@@ -402,7 +402,11 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	                                            NULL);
 
 	if (md.orientation) {
-		tracker_resource_set_string (metadata, "nfo:orientation", md.orientation);
+		TrackerResource *orientation;
+
+		orientation = tracker_resource_new (md.orientation);
+		tracker_resource_set_relation (metadata, "nfo:orientation", orientation);
+		g_object_unref (orientation);
 	}
 
 	if (md.copyright) {
@@ -410,7 +414,11 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	}
 
 	if (md.white_balance) {
-		tracker_resource_set_string (metadata, "nmm:whiteBalance", md.white_balance);
+		TrackerResource *white_balance;
+
+		white_balance = tracker_resource_new (md.white_balance);
+		tracker_resource_set_relation (metadata, "nmm:whiteBalance", white_balance);
+		g_object_unref (white_balance);
 	}
 
 	if (md.fnumber) {
@@ -421,7 +429,11 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	}
 
 	if (md.flash) {
-		tracker_resource_set_string (metadata, "nmm:flash", md.flash);
+		TrackerResource *flash;
+
+		flash = tracker_resource_new (md.flash);
+		tracker_resource_set_relation (metadata, "nmm:flash", flash);
+		g_object_unref (flash);
 	}
 
 	if (md.focal_length) {
@@ -461,7 +473,11 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	}
 
 	if (md.metering_mode) {
-		tracker_resource_set_string(metadata, "nmm:meteringMode", md.metering_mode);
+		TrackerResource *metering;
+
+		metering = tracker_resource_new (md.metering_mode);
+		tracker_resource_set_relation (metadata, "nmm:meteringMode", metering);
+		g_object_unref (metering);
 	}
 
 	if (md.creator) {
